import {FC, useEffect, useState} from "react";
import Taro, {useReachBottom} from "@tarojs/taro";
import {View} from "@tarojs/components";
import {Courses, CoursesKey, publicApi} from "@/api/public";
import VideoCover from "@/components/videoCover/videoCover";
import styles from '../index.module.scss'
import {formatMinute} from "@/utils/time";
import {userApi} from "@/api";

interface Props {
  categoryKey: CoursesKey
}

export const VideoList: FC<Props> = ({categoryKey}) => {
  const [data, setData] = useState<Courses>({
    is_finished: [],
    is_required: [],
    is_not_finished: [],
    is_not_required: []
  })
  const [page, setPage] = useState(1)
  const [records, setRecords] = useState<LearnRecord[]>([])

  async function getData() {
    try {
      const res = await publicApi.course({page: page, pageSize: 10})
      const oldData: Courses = JSON.parse(JSON.stringify(data))
      oldData.is_finished.push(...res.is_finished)
      oldData.is_required.push(...res.is_required)
      oldData.is_not_finished.push(...res.is_not_finished)
      oldData.is_not_required.push(...res.is_not_required)
      setData(oldData)
    } catch (e) {
    }
  }

  async function getRecords() {
    try {
      const {user_course_records} = await userApi.learningRecord()
      setRecords(user_course_records)
    } catch (e) {
    }
  }


  function rateOfLearning(id: number, class_hour: number): JSX.Element {
    switch (categoryKey) {
      case "is_required":
      case "is_not_required":
        const find = records.find(d => d?.course_id === id)
        if (find) {
          return (<View>{`共${class_hour}节/已学${find.finished_count}节`}</View>)
        }
        return (<View>{`共${class_hour}节/已学0节`}</View>)
      case "is_not_finished":
        return (<View>{`共${class_hour}节/已学0节`}</View>)
      case "is_finished":
        return (<View>{`共${class_hour}节/已学${class_hour}节`}</View>)
    }
    return (<View>sd</View>)
  }

  useReachBottom(() => {
    setPage(page + 1)
  })

  Taro.useDidShow(() => {
    getRecords()
  })

  useEffect(() => {
    getData()
  }, [page])
  return (
    <View className={'py-2 flex justify-between flex-wrap ' + styles.videoListBox}>
      {data?.[categoryKey]?.map(c =>
        <VideoCover
          thumb={c.thumb}
          title={c.title}
          id={c.id}
          depId={c.id}
          time={formatMinute(c.course_duration)}
          content={rateOfLearning(c.id, c.class_hour)}
        />)}
    </View>
  )
}

